@@ -14,9 +14,4 @@ It didn't matter how hard we tried
 @author: KING
 """
 
-def jujube():
-    print ('吃枣')
- 
-
-def pill():
-    print ('吃枣2')
\ No newline at end of file
+print('哈哈哈哈哈宝宝')
\ No newline at end of file
